==> ZenTaoPMS.max2.4.php5.3_5.6.zip: zentaopms/module/my/ext/model/class/effort.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPrwF68j4L+6ihpgDgFWGxIjuZ6qE4HIunynBlfhIiMEyBkObnxEfnYSs7HsUO1Iyxt3xmfM4
iPSFXj6JzzYQd7sDoQnSntpyab8jYmG3btfUg7MrcsY5yiz21pbcy9Bur+TJPRP6wv6isGoiDVMI
G+Q2NlLn/0qP2SHZP47lhqZ+HC+NoI4VunT4R7RMXwXgsDO8LurzCGewveesOlYwpeAAYLOVdL2L
TtCcqSRRCFcD9Bytt6+H2txIAsxjewJzY/Z5j6B/hr6pI86pth5kVHNMRTYkfgpspeXTHoo9swcI
8g6UxbolDhbjo5t7bTI4BSBMRHRJsscUonCbMen0doKMJuJDlsrEFr/NEvxNgnJFyc6DcARYMU+m
fe7XZW0FLlkVdyMRrUTf3LD9sBNTFCPH0KP2QGOPgVBp7T1M2lDQybx2fDgKt/M4K4khkcWxyOtM
IrwxXfebpVnVpRbQZBXP5ARVVLiW0sGkqSoUbkAmvEHbqjggzgwezUk8kue8cE4iA/9agOD1SG2h
A0PlyWTuoS8N2HGcBsAkriyh5O9eJ9KsAHi1lT4csDuDgUNcgBnjrfXrtEYSWKcpUO3mDtSal6t/
nslzJ6rXcBZ3gSRg6BX0YPDIS0YpGO2V0XVuEKqjoZly9lfAH45S46TDfdUk4IOSlu83tgzqZJiw
IVq/A3cDU8dFcoNx/1nz30YZkh+4vD/Iep+b7zkuyuuEoKqwhUhlxYzg8KODzP0NVspU+lJ0qrGg
JdubWV48D1di2sAW5iVZvpV2/PHVi+geif+v7p+cM/NzwdMW6fFJ89x4GIBsepZxS//kBEOSHRvB
2zvtZWx8UBaDbcZueknID/rzbCiEgjwlwZq=

==> ZenTaoPMS.max2.7.php5.3_5.6.zip: zentaopms/module/my/ext/model/class/effort.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPubgtI8Si2KLPzz80QrTvgi5kMI8OHt+tVfrRwRyEinMs3JLZqn550vhSQ7YXzeIL7wiIQeV
cunCYs2wRpfGSs7cn5kJrW3YlxBOrs6iPc6jjz/DIfxPBL/dnajdsFSXPudhwCiAEVYq8n2U3utK
eClv8QOUWMEkxz1XJOgs4Cr+Jw+397pHJXvNx/UcNesDwrfAV2YKpICr2lidSq15bpfALbNeKpDq
v7qKzyKMGdElx4yV/jN0NWx4uUIgUDwYc441U2h7IQZpn8orLA5X/zPWJx4rlXTiSRa6vUYpbT06
7FXFyj8vVYzpD6tq0HkXCwqjs3Tbbb/sltNy3AB3zUNG74GwDqS/mk4Mhn6yePKApEzuvtcdl6Yj
87upKJu1pUrtCngLnpUgqPIG/nk7viPkTLTokMIFdBcc0Rda7UzBbE4DMzTQY8sWSbat74pUOUYc
QjE6Lnhz8VdvCmsPzlzVSUW3EWGvYnPa6XBgN8ncJelOQvgIQEDi7rwCo2F9twj7m0lAmw3qzbYs
Im8AYIgCPMG6SxTAMzQvL5g3cw4bmrJZNfLL/mxj3ND5qEeCHEnW/L899ix6D5tKCULD0sBr+wuh
FffeFni4MWDQecgU3ArnjmIy2iv+sAACzgPbAhhxiZQ5KTKAVx2qjR25aWmOHMF3+USmR5CkXnMY
ugq+NlOClIjsRRT7Qz49xeSCEahg0bX+7QsJUMpGlHj37vSToMIyoH2j4iPGMq1CJIcPk4QoUykc
kNmJrvsP3G0dEgm3BXUeqCoY5H0h5fp48pMXlhdyHbfMlDJYraB0WHyaCGPyQFJT5T1pphqZcdep
v7BwQI5YDrp1oWaipHgpgJqtYCG4oB4TeU1s
